# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tarot/bot.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0ftarot/bot.proto\x12\x05tarot\x1a\x1bgoogle/protobuf/empty.proto\"L\n\rMessageAction\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x03url\x18\x02 \x01(\tH\x00\x12\x12\n\x08\x63\x61llback\x18\x03 \x01(\tH\x00\x42\t\n\x07payload\"\xa9\x02\n\x12SendMessageRequest\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0e\n\x06\x62ot_id\x18\x02 \x01(\x03\x12%\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32\x14.tarot.MessageAction\x12\x15\n\rrecipient_ids\x18\x04 \x03(\x03\x12\x15\n\x08hook_tag\x18\x05 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tis_silent\x18\x06 \x01(\x08H\x01\x88\x01\x01\x12\x39\n\x08metadata\x18\x07 \x03(\x0b\x32\'.tarot.SendMessageRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0b\n\t_hook_tagB\x0c\n\n_is_silent\"\xb8\x01\n\x12TriggerHookRequest\x12\x10\n\x08hook_tag\x18\x01 \x01(\t\x12\x0e\n\x06\x62ot_id\x18\x02 \x01(\x03\x12\x14\n\x0crecipient_id\x18\x03 \x01(\x03\x12\x39\n\x08metadata\x18\x04 \x03(\x0b\x32\'.tarot.TriggerHookRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"L\n\x11MessageSentStatus\x12\x14\n\x0crecipient_id\x18\x01 \x01(\x03\x12!\n\x06status\x18\x02 \x01(\x0e\x32\x11.tarot.SentStatus\"A\n\x13SendMessageResponse\x12*\n\x08statuses\x18\x01 \x03(\x0b\x32\x18.tarot.MessageSentStatus\"d\n\rRefundRequest\x12\x0e\n\x06\x62ot_id\x18\x01 \x01(\x03\x12\x14\n\x0crecipient_id\x18\x02 \x01(\x03\x12\x16\n\x0etransaction_id\x18\x03 \x01(\t\x12\x15\n\rrefund_reason\x18\x04 \x01(\t*\xa6\x01\n\x11MessageActionType\x12#\n\x1fMESSAGE_ACTION_TYPE_UNSPECIFIED\x10\x00\x12\x1b\n\x17MESSAGE_ACTION_TYPE_URL\x10\x01\x12 \n\x1cMESSAGE_ACTION_TYPE_CALLBACK\x10\x02\x12-\n)MESSAGE_ACTION_TYPE_CALLBACK_PARAMETRIZED\x10\x03*t\n\nSentStatus\x12\x1b\n\x17SENT_STATUS_UNSPECIFIED\x10\x00\x12\x14\n\x10SENT_STATUS_SENT\x10\x01\x12\x15\n\x11SENT_STATUS_ERROR\x10\x02\x12\x1c\n\x18SENT_STATUS_USER_BLOCKED\x10\x03\x32\xdc\x01\n\nBotManager\x12\x46\n\x0bSendMessage\x12\x19.tarot.SendMessageRequest\x1a\x1a.tarot.SendMessageResponse\"\x00\x12\x45\n\x0eTriggerBotHook\x12\x19.tarot.TriggerHookRequest\x1a\x16.google.protobuf.Empty\"\x00\x12?\n\rPaymentRefund\x12\x14.tarot.RefundRequest\x1a\x16.google.protobuf.Empty\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tarot.bot_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _SENDMESSAGEREQUEST_METADATAENTRY._options = None
  _SENDMESSAGEREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _TRIGGERHOOKREQUEST_METADATAENTRY._options = None
  _TRIGGERHOOKREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _globals['_MESSAGEACTIONTYPE']._serialized_start=868
  _globals['_MESSAGEACTIONTYPE']._serialized_end=1034
  _globals['_SENTSTATUS']._serialized_start=1036
  _globals['_SENTSTATUS']._serialized_end=1152
  _globals['_MESSAGEACTION']._serialized_start=55
  _globals['_MESSAGEACTION']._serialized_end=131
  _globals['_SENDMESSAGEREQUEST']._serialized_start=134
  _globals['_SENDMESSAGEREQUEST']._serialized_end=431
  _globals['_SENDMESSAGEREQUEST_METADATAENTRY']._serialized_start=357
  _globals['_SENDMESSAGEREQUEST_METADATAENTRY']._serialized_end=404
  _globals['_TRIGGERHOOKREQUEST']._serialized_start=434
  _globals['_TRIGGERHOOKREQUEST']._serialized_end=618
  _globals['_TRIGGERHOOKREQUEST_METADATAENTRY']._serialized_start=357
  _globals['_TRIGGERHOOKREQUEST_METADATAENTRY']._serialized_end=404
  _globals['_MESSAGESENTSTATUS']._serialized_start=620
  _globals['_MESSAGESENTSTATUS']._serialized_end=696
  _globals['_SENDMESSAGERESPONSE']._serialized_start=698
  _globals['_SENDMESSAGERESPONSE']._serialized_end=763
  _globals['_REFUNDREQUEST']._serialized_start=765
  _globals['_REFUNDREQUEST']._serialized_end=865
  _globals['_BOTMANAGER']._serialized_start=1155
  _globals['_BOTMANAGER']._serialized_end=1375
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from tarot import bot_pb2 as tarot_dot_bot__pb2


class BotManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SendMessage = channel.unary_unary(
                '/tarot.BotManager/SendMessage',
                request_serializer=tarot_dot_bot__pb2.SendMessageRequest.SerializeToString,
                response_deserializer=tarot_dot_bot__pb2.SendMessageResponse.FromString,
                )
        self.TriggerBotHook = channel.unary_unary(
                '/tarot.BotManager/TriggerBotHook',
                request_serializer=tarot_dot_bot__pb2.TriggerHookRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.PaymentRefund = channel.unary_unary(
                '/tarot.BotManager/PaymentRefund',
                request_serializer=tarot_dot_bot__pb2.RefundRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class BotManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SendMessage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerBotHook(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PaymentRefund(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BotManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SendMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.SendMessage,
                    request_deserializer=tarot_dot_bot__pb2.SendMessageRequest.FromString,
                    response_serializer=tarot_dot_bot__pb2.SendMessageResponse.SerializeToString,
            ),
            'TriggerBotHook': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerBotHook,
                    request_deserializer=tarot_dot_bot__pb2.TriggerHookRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'PaymentRefund': grpc.unary_unary_rpc_method_handler(
                    servicer.PaymentRefund,
                    request_deserializer=tarot_dot_bot__pb2.RefundRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'tarot.BotManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class BotManager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SendMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.BotManager/SendMessage',
            tarot_dot_bot__pb2.SendMessageRequest.SerializeToString,
            tarot_dot_bot__pb2.SendMessageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerBotHook(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.BotManager/TriggerBotHook',
            tarot_dot_bot__pb2.TriggerHookRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PaymentRefund(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/tarot.BotManager/PaymentRefund',
            tarot_dot_bot__pb2.RefundRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BotGroup(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    BOT_GROUP_UNSPECIFIED: _ClassVar[BotGroup]
    BOT_GROUP_TAROT: _ClassVar[BotGroup]

class BotProvider(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    BOT_PROVIDER_UNSPECIFIED: _ClassVar[BotProvider]
    BOT_PROVIDER_TELEGRAM: _ClassVar[BotProvider]
    BOT_PROVIDER_SLACK: _ClassVar[BotProvider]
    BOT_PROVIDER_VIBER: _ClassVar[BotProvider]
BOT_GROUP_UNSPECIFIED: BotGroup
BOT_GROUP_TAROT: BotGroup
BOT_PROVIDER_UNSPECIFIED: BotProvider
BOT_PROVIDER_TELEGRAM: BotProvider
BOT_PROVIDER_SLACK: BotProvider
BOT_PROVIDER_VIBER: BotProvider

class PricingPlan(_message.Message):
    __slots__ = ["id", "name", "description", "price", "credits"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    PRICE_FIELD_NUMBER: _ClassVar[int]
    CREDITS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    price: int
    credits: int
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., price: _Optional[int] = ..., credits: _Optional[int] = ...) -> None: ...

class RetentionConfig(_message.Message):
    __slots__ = ["enabled", "frequency", "prompt", "bot_hook"]
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    FREQUENCY_FIELD_NUMBER: _ClassVar[int]
    PROMPT_FIELD_NUMBER: _ClassVar[int]
    BOT_HOOK_FIELD_NUMBER: _ClassVar[int]
    enabled: bool
    frequency: str
    prompt: str
    bot_hook: str
    def __init__(self, enabled: bool = ..., frequency: _Optional[str] = ..., prompt: _Optional[str] = ..., bot_hook: _Optional[str] = ...) -> None: ...

class TarotBotConfig(_message.Message):
    __slots__ = ["spread_prompt", "pricing_plans", "default_language"]
    SPREAD_PROMPT_FIELD_NUMBER: _ClassVar[int]
    PRICING_PLANS_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    spread_prompt: str
    pricing_plans: _containers.RepeatedCompositeFieldContainer[PricingPlan]
    default_language: str
    def __init__(self, spread_prompt: _Optional[str] = ..., pricing_plans: _Optional[_Iterable[_Union[PricingPlan, _Mapping]]] = ..., default_language: _Optional[str] = ...) -> None: ...

class Bot(_message.Message):
    __slots__ = ["id", "token", "group", "provider", "name", "tarot_config", "retention_config"]
    ID_FIELD_NUMBER: _ClassVar[int]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TAROT_CONFIG_FIELD_NUMBER: _ClassVar[int]
    RETENTION_CONFIG_FIELD_NUMBER: _ClassVar[int]
    id: int
    token: str
    group: BotGroup
    provider: BotProvider
    name: str
    tarot_config: TarotBotConfig
    retention_config: RetentionConfig
    def __init__(self, id: _Optional[int] = ..., token: _Optional[str] = ..., group: _Optional[_Union[BotGroup, str]] = ..., provider: _Optional[_Union[BotProvider, str]] = ..., name: _Optional[str] = ..., tarot_config: _Optional[_Union[TarotBotConfig, _Mapping]] = ..., retention_config: _Optional[_Union[RetentionConfig, _Mapping]] = ...) -> None: ...

class RetrieveBotsRequest(_message.Message):
    __slots__ = ["group", "provider"]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    group: BotGroup
    provider: BotProvider
    def __init__(self, group: _Optional[_Union[BotGroup, str]] = ..., provider: _Optional[_Union[BotProvider, str]] = ...) -> None: ...

class RetrieveBotsResponse(_message.Message):
    __slots__ = ["bots"]
    BOTS_FIELD_NUMBER: _ClassVar[int]
    bots: _containers.RepeatedCompositeFieldContainer[Bot]
    def __init__(self, bots: _Optional[_Iterable[_Union[Bot, _Mapping]]] = ...) -> None: ...

class RetrieveBotRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    def __init__(self, id: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tarot/bots_master.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17tarot/bots_master.proto\x12\x05tarot\"\\\n\x0bPricingPlan\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\r\n\x05price\x18\x04 \x01(\x05\x12\x0f\n\x07\x63redits\x18\x05 \x01(\x05\"i\n\x0fRetentionConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x11\n\tfrequency\x18\x02 \x01(\t\x12\x0e\n\x06prompt\x18\x03 \x01(\t\x12\x15\n\x08\x62ot_hook\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_bot_hook\"\x86\x01\n\x0eTarotBotConfig\x12\x15\n\rspread_prompt\x18\x01 \x01(\t\x12)\n\rpricing_plans\x18\x02 \x03(\x0b\x32\x12.tarot.PricingPlan\x12\x1d\n\x10\x64\x65\x66\x61ult_language\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x13\n\x11_default_language\"\xdf\x01\n\x03\x42ot\x12\n\n\x02id\x18\x01 \x01(\x03\x12\r\n\x05token\x18\x02 \x01(\t\x12\x1e\n\x05group\x18\x03 \x01(\x0e\x32\x0f.tarot.BotGroup\x12$\n\x08provider\x18\x04 \x01(\x0e\x32\x12.tarot.BotProvider\x12\x0c\n\x04name\x18\x05 \x01(\t\x12-\n\x0ctarot_config\x18\x06 \x01(\x0b\x32\x15.tarot.TarotBotConfigH\x00\x12\x30\n\x10retention_config\x18\x07 \x01(\x0b\x32\x16.tarot.RetentionConfigB\x08\n\x06\x63onfig\"[\n\x13RetrieveBotsRequest\x12\x1e\n\x05group\x18\x01 \x01(\x0e\x32\x0f.tarot.BotGroup\x12$\n\x08provider\x18\x02 \x01(\x0e\x32\x12.tarot.BotProvider\"0\n\x14RetrieveBotsResponse\x12\x18\n\x04\x62ots\x18\x01 \x03(\x0b\x32\n.tarot.Bot\" \n\x12RetrieveBotRequest\x12\n\n\x02id\x18\x01 \x01(\x03*:\n\x08\x42otGroup\x12\x19\n\x15\x42OT_GROUP_UNSPECIFIED\x10\x00\x12\x13\n\x0f\x42OT_GROUP_TAROT\x10\x01*v\n\x0b\x42otProvider\x12\x1c\n\x18\x42OT_PROVIDER_UNSPECIFIED\x10\x00\x12\x19\n\x15\x42OT_PROVIDER_TELEGRAM\x10\x01\x12\x16\n\x12\x42OT_PROVIDER_SLACK\x10\x02\x12\x16\n\x12\x42OT_PROVIDER_VIBER\x10\x03\x32\x8b\x01\n\nBotsMaster\x12G\n\x0cRetrieveBots\x12\x1a.tarot.RetrieveBotsRequest\x1a\x1b.tarot.RetrieveBotsResponse\x12\x34\n\x0bRetrieveBot\x12\x19.tarot.RetrieveBotRequest\x1a\n.tarot.Botb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tarot.bots_master_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_BOTGROUP']._serialized_start=775
  _globals['_BOTGROUP']._serialized_end=833
  _globals['_BOTPROVIDER']._serialized_start=835
  _globals['_BOTPROVIDER']._serialized_end=953
  _globals['_PRICINGPLAN']._serialized_start=34
  _globals['_PRICINGPLAN']._serialized_end=126
  _globals['_RETENTIONCONFIG']._serialized_start=128
  _globals['_RETENTIONCONFIG']._serialized_end=233
  _globals['_TAROTBOTCONFIG']._serialized_start=236
  _globals['_TAROTBOTCONFIG']._serialized_end=370
  _globals['_BOT']._serialized_start=373
  _globals['_BOT']._serialized_end=596
  _globals['_RETRIEVEBOTSREQUEST']._serialized_start=598
  _globals['_RETRIEVEBOTSREQUEST']._serialized_end=689
  _globals['_RETRIEVEBOTSRESPONSE']._serialized_start=691
  _globals['_RETRIEVEBOTSRESPONSE']._serialized_end=739
  _globals['_RETRIEVEBOTREQUEST']._serialized_start=741
  _globals['_RETRIEVEBOTREQUEST']._serialized_end=773
  _globals['_BOTSMASTER']._serialized_start=956
  _globals['_BOTSMASTER']._serialized_end=1095
# @@protoc_insertion_point(module_scope)
